@@ -20,6 +20,7 @@ from mistral.actions import base
 from mistral import context
 from mistral.utils.openstack import keystone as keystone_utils
 from mistralclient.api import client as mistral_client
+from novaclient.client import Client as nova_client
 from swiftclient import client as swift_client
 
 
@@ -44,11 +45,22 @@ class TripleOAction(base.Action):
 
         ironic_endpoint = keystone_utils.get_endpoint_for_project('ironic')
 
+        # FIXME(lucasagomes): Use ironicclient.get_client() instead
+        # of ironicclient.Client(). Client() might cause errors since
+        # it doesn't verify the provided arguments, get_client() is the
+        # prefered way
         return ironicclient.Client(
             ironic_endpoint.url,
             token=ctx.auth_token,
             region_name=ironic_endpoint.region,
-            os_ironic_api_version='1.11'
+            os_ironic_api_version='1.11',
+            # FIXME(lucasagomes):Paramtetize max_retries and
+            # max_interval. At the moment since we are dealing with
+            # a critical bug (#1612622) let's just hardcode the times
+            # here since the right fix does involve multiple projects
+            # (tripleo-ci and python-tripleoclient beyong tripleo-common)
+            max_retries=12,
+            retry_interval=5,
         )
 
     def _get_baremetal_introspection_client(self):
@@ -98,3 +110,14 @@ class TripleOAction(base.Action):
                                    mistral_url=mistral_endpoint.url)
 
         return mc
+
+    def _get_compute_client(self):
+        ctx = context.ctx()
+        keystone_endpoint = keystone_utils.get_endpoint_for_project('keystone')
+        nova_endpoint = keystone_utils.get_endpoint_for_project('nova')
+
+        nc = nova_client(2, username=ctx.user_name, auth_token=ctx.auth_token,
+                         auth_url=keystone_endpoint.url, url=nova_endpoint.url,
+                         project_id=ctx.project_id)
+        nc.client.management_url = nova_endpoint.url
+        return nc
